pub fn calculate_directory_size<P: AsRef<Path>>(
path: P,
options: &ScanOptions,
) -> u64Expand description
Calculates the total size of a directory in bytes
pub fn calculate_directory_size<P: AsRef<Path>>(
path: P,
options: &ScanOptions,
) -> u64Calculates the total size of a directory in bytes